@@ -3,8 +3,15 @@ use strict;
 use warnings;
 
 use Test2::API::Instance;
-use Test2::API qw/test2_init_done test2_ipc test2_stack test2_pid test2_tid/;
 use Test2::Util qw/get_tid/;
+use Test2::API qw{
+    test2_init_done
+    test2_ipc
+    test2_ipc_enable_polling
+    test2_pid
+    test2_stack
+    test2_tid
+};
 
 use Carp qw/confess/;
 
@@ -17,8 +24,7 @@ sub import {
     confess "Cannot add IPC in a child process" if test2_pid() != $$;
     confess "Cannot add IPC in a child thread"  if test2_tid() != get_tid();
 
-    my $INST = Test2::API::Instance::_internal_use_only_private_instance();
-    $INST->set_ipc(_make_ipc());
+    Test2::API::_set_ipc(_make_ipc());
     apply_ipc(test2_stack());
 
     goto &Exporter::import;
@@ -56,6 +62,8 @@ sub apply_ipc {
         $ipc->add_hub($hub->hid);
     }
 
+    test2_ipc_enable_polling();
+
     return $ipc;
 }
 
